Statistics
==========

Information
-----------
Name:
  ``pyplanet.apps.core.statistics``
Depends on:
  ``core.maniaplanet``
Game:
  TrackMania & ShootMania

Features
--------
This app keeps track of the general statistics across the games.

Commands
--------

Display Ideal Checkpoints
~~~~~~~~~~~~~~~~~~~~~~~~~
Command:
  ``/cpcomparison``
Parameters:
  None.
Functionality:
  Find out the best route by comparing checkpoint times with all local records (to potentially find the ideal route/lines)
Required permission:
  None.

Display Top Donators
~~~~~~~~~~~~~~~~~~~~
Command:
  ``/topdons``
Parameters:
  None.
Functionality:
  Display a list of the top donating players on the server.
Required permission:
  None.

Display Top Active
~~~~~~~~~~~~~~~~~~
Command:
  ``/topactive``
Parameters:
  None.
Functionality:
  Display a list of the top active players on the server.
Required permission:
  None.

Display Top Players (based on records) (TM only)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Command:
  ``/topsums``
Parameters:
  None.
Functionality:
  Display a list of best players according to the top 3 records on maps.
Required permission:
  None.

Display personal score progression on map (TM only)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Command:
  ``/scoreprogression``
Parameters:
  None.
Functionality:
  Display a list with past scores on the current map.
Required permission:
  None.
